(require 'apropospriate-theme)

(deftheme apropospriate-dark "The dark variant of the Apropospriate color theme")

(create-apropospriate-theme 'dark 'apropospriate-dark)

(provide-theme 'apropospriate-dark)
